@@ -17,7 +17,12 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
-from .literals import ConnectionTypeType, MemberPermissionsType, PermissionsType
+from .literals import (
+    ConnectionTypeType,
+    ManagedCredentialsActionType,
+    MemberPermissionsType,
+    PermissionsType,
+)
 from .paginator import DescribeEnvironmentMembershipsPaginator, ListEnvironmentsPaginator
 from .type_defs import (
     CreateEnvironmentEC2ResultTypeDef,
@@ -62,7 +67,7 @@ class Exceptions:
 
 class Cloud9Client(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html)
     """
 
@@ -78,7 +83,7 @@ class Cloud9Client(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#can_paginate)
         """
 
@@ -94,14 +99,15 @@ class Cloud9Client(BaseClient):
         automaticStopTimeMinutes: int = None,
         ownerArn: str = None,
         tags: List["TagTypeDef"] = None,
-        connectionType: ConnectionTypeType = None
+        connectionType: ConnectionTypeType = None,
+        dryRun: bool = None
     ) -> CreateEnvironmentEC2ResultTypeDef:
         """
         Creates an Cloud9 development environment, launches an Amazon Elastic Compute
         Cloud (Amazon EC2) instance, and then connects from the instance to the
         environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.create_environment_ec2)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.create_environment_ec2)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#create_environment_ec2)
         """
 
@@ -111,7 +117,7 @@ class Cloud9Client(BaseClient):
         """
         Adds an environment member to an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.create_environment_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.create_environment_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#create_environment_membership)
         """
 
@@ -119,7 +125,7 @@ class Cloud9Client(BaseClient):
         """
         Deletes an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.delete_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.delete_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#delete_environment)
         """
 
@@ -127,7 +133,7 @@ class Cloud9Client(BaseClient):
         """
         Deletes an environment member from an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.delete_environment_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.delete_environment_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#delete_environment_membership)
         """
 
@@ -144,7 +150,7 @@ class Cloud9Client(BaseClient):
         Gets information about environment members for an Cloud9 development
         environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.describe_environment_memberships)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.describe_environment_memberships)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#describe_environment_memberships)
         """
 
@@ -154,7 +160,7 @@ class Cloud9Client(BaseClient):
         """
         Gets status information for an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.describe_environment_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.describe_environment_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#describe_environment_status)
         """
 
@@ -164,7 +170,7 @@ class Cloud9Client(BaseClient):
         """
         Gets information about Cloud9 development environments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.describe_environments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.describe_environments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#describe_environments)
         """
 
@@ -178,7 +184,7 @@ class Cloud9Client(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#generate_presigned_url)
         """
 
@@ -188,7 +194,7 @@ class Cloud9Client(BaseClient):
         """
         Gets a list of Cloud9 development environment identifiers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.list_environments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.list_environments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#list_environments)
         """
 
@@ -196,7 +202,7 @@ class Cloud9Client(BaseClient):
         """
         Gets a list of the tags associated with an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#list_tags_for_resource)
         """
 
@@ -204,7 +210,7 @@ class Cloud9Client(BaseClient):
         """
         Adds tags to an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#tag_resource)
         """
 
@@ -212,17 +218,22 @@ class Cloud9Client(BaseClient):
         """
         Removes tags from an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#untag_resource)
         """
 
     def update_environment(
-        self, *, environmentId: str, name: str = None, description: str = None
+        self,
+        *,
+        environmentId: str,
+        name: str = None,
+        description: str = None,
+        managedCredentialsAction: ManagedCredentialsActionType = None
     ) -> Dict[str, Any]:
         """
         Changes the settings of an existing Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.update_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.update_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#update_environment)
         """
 
@@ -233,7 +244,7 @@ class Cloud9Client(BaseClient):
         Changes the settings of an existing environment member for an Cloud9 development
         environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Client.update_environment_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Client.update_environment_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#update_environment_membership)
         """
 
@@ -242,7 +253,7 @@ class Cloud9Client(BaseClient):
         self, operation_name: Literal["describe_environment_memberships"]
     ) -> DescribeEnvironmentMembershipsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/paginators.html#describeenvironmentmembershipspaginator)
         """
 
@@ -251,6 +262,6 @@ class Cloud9Client(BaseClient):
         self, operation_name: Literal["list_environments"]
     ) -> ListEnvironmentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.19/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/paginators.html#listenvironmentspaginator)
         """
